@@ -100,7 +100,8 @@ bool RichTextComposerNg::processAutoCorrection(QKeyEvent *e)
                 const bool addSpace = d->autoCorrection->autocorrect(richText, *document(), position);
                 QTextCursor cur = textCursor();
                 cur.setPosition(position);
-                if (overwriteMode() && e->key() == Qt::Key_Space) {
+                const bool spacePressed = (e->key() == Qt::Key_Space);
+                if (overwriteMode() && spacePressed) {
                     if (addSpace) {
                         const QChar insertChar = QLatin1Char(' ');
                         if (!cur.atBlockEnd()) {
@@ -114,7 +115,7 @@ bool RichTextComposerNg::processAutoCorrection(QKeyEvent *e)
                         setTextCursor(cur);
                     }
                 } else {
-                    const bool spacePressed = (e->key() == Qt::Key_Space);
+
                     const QChar insertChar = spacePressed ? QLatin1Char(' ') : QLatin1Char('\n');
                     if (richText && !isSpecial(initialTextFormat)) {
                         if ((spacePressed && addSpace) || !spacePressed) {
@@ -359,7 +360,6 @@ void RichTextComposerNg::insertSignature(const KIdentityManagement::Signature &s
                 composerControler()->composerImages()->loadImage(image->image, image->name, image->name);
             }
         }
-
     }
 }
 
@@ -367,3 +367,48 @@ QString RichTextComposerNg::toCleanHtml() const
 {
     return d->toCleanHtml();
 }
+
+void RichTextComposerNg::forceAutoCorrection(bool selectedText)
+{
+    if (document()->isEmpty()) {
+        return;
+    }
+    if (d->autoCorrection && d->autoCorrection->isEnabledAutoCorrection()) {
+        const bool richText = (textMode() == RichTextComposer::Rich);
+        const int initialPosition = textCursor().position();
+        QTextCursor cur = textCursor();
+        cur.beginEditBlock();
+        if (selectedText && cur.hasSelection()) {
+            const int positionStart = qMin(cur.selectionEnd(), cur.selectionStart());
+            const int positionEnd = qMax(cur.selectionEnd(), cur.selectionStart());
+            cur.setPosition(positionStart);
+            int cursorPosition = positionStart;
+            while (cursorPosition < positionEnd) {
+                if (isLineQuoted(cur.block().text())) {
+                    cur.movePosition(QTextCursor::NextBlock);
+                } else {
+                    cur.movePosition(QTextCursor::NextWord);
+                }
+                cursorPosition = cur.position();
+                d->autoCorrection->autocorrect(richText, *document(), cursorPosition);
+            }
+        } else {
+            cur.movePosition(QTextCursor::Start);
+            while (!cur.atEnd()) {
+                if (isLineQuoted(cur.block().text())) {
+                    cur.movePosition(QTextCursor::NextBlock);
+                } else {
+                    cur.movePosition(QTextCursor::NextWord);
+                }
+                int cursorPosition = cur.position();
+                d->autoCorrection->autocorrect(richText, *document(), cursorPosition);
+            }
+        }
+        cur.endEditBlock();
+        if (cur.position() != initialPosition) {
+            cur.setPosition(initialPosition);
+            setTextCursor(cur);
+        }
+
+    }
+}
