@@ -47,14 +47,16 @@ class PluginEditorCheckBeforeSendInfo
 {
 public:
     PluginEditorCheckBeforeSendInfo()
-        : plugin(Q_NULLPTR)
+        : plugin(Q_NULLPTR),
+          isEnabled(true)
     {
 
     }
-    QString saveName() const;
-
-    KPluginMetaData metaData;
+    QString metaDataFileNameBaseName;
+    QString metaDataFileName;
+    PimCommon::PluginUtilData pluginData;
     PluginEditorCheckBeforeSend *plugin;
+    bool isEnabled;
 };
 
 Q_GLOBAL_STATIC(PluginEditorCheckBeforeSendManagerInstancePrivate, sInstance)
@@ -79,31 +81,62 @@ public:
     QVector<PluginEditorCheckBeforeSend *> pluginsList() const;
     bool initializePlugins();
     QVector<PluginEditorCheckBeforeSendInfo> mPluginList;
+    QString configPrefixSettingKey() const;
+    QString configGroupName() const;
+    QVector<PimCommon::PluginUtilData> pluginsDataList() const;
+    PluginEditorCheckBeforeSend *pluginFromIdentifier(const QString &id);
+private:
+    QVector<PimCommon::PluginUtilData> mPluginDataList;
     PluginEditorCheckBeforeSendManager *q;
 };
 
+QString PluginEditorCheckBeforeSendManagerPrivate::configGroupName() const
+{
+    return QStringLiteral("KMailPluginCheckBefore");
+}
+
+QString PluginEditorCheckBeforeSendManagerPrivate::configPrefixSettingKey() const
+{
+    return QStringLiteral("PluginCheckBefore");
+}
+
+QVector<PimCommon::PluginUtilData> PluginEditorCheckBeforeSendManagerPrivate::pluginsDataList() const
+{
+    return mPluginDataList;
+}
+
 bool PluginEditorCheckBeforeSendManagerPrivate::initializePlugins()
 {
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kmail"), [](const KPluginMetaData & md) {
         return md.serviceTypes().contains(QStringLiteral("KMailEditor/PluginCheckBeforeSend"));
     });
 
+    const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
+
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
     QSet<QString> unique;
     while (i.hasPrevious()) {
         PluginEditorCheckBeforeSendInfo info;
-        info.metaData = i.previous();
-        if (pluginVersion() == info.metaData.version()) {
+        const KPluginMetaData data = i.previous();
+
+        //1) get plugin data => name/description etc.
+        info.pluginData = PimCommon::PluginUtil::createPluginMetaData(data);
+        //2) look at if plugin is activated
+        const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
+        info.isEnabled = isPluginActivated;
+        info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
+        info.metaDataFileName = data.fileName();
+        if (pluginVersion() == data.version()) {
             // only load plugins once, even if found multiple times!
-            if (unique.contains(info.saveName())) {
+            if (unique.contains(info.metaDataFileNameBaseName)) {
                 continue;
             }
             info.plugin = Q_NULLPTR;
             mPluginList.push_back(info);
-            unique.insert(info.saveName());
+            unique.insert(info.metaDataFileNameBaseName);
         } else {
-            qCWarning(MESSAGECOMPOSER_LOG) << "Plugin " << info.metaData.name() << " doesn't have correction plugin version. It will not be loaded.";
+            qCWarning(MESSAGECOMPOSER_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
     }
     QVector<PluginEditorCheckBeforeSendInfo>::iterator end(mPluginList.end());
@@ -115,9 +148,12 @@ bool PluginEditorCheckBeforeSendManagerPrivate::initializePlugins()
 
 void PluginEditorCheckBeforeSendManagerPrivate::loadPlugin(PluginEditorCheckBeforeSendInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaData.fileName());
+    KPluginLoader pluginLoader(item->metaDataFileName);
     if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<PluginEditorCheckBeforeSend>(q, QVariantList() << item->saveName());
+        item->plugin = pluginLoader.factory()->create<PluginEditorCheckBeforeSend>(q, QVariantList() << item->metaDataFileNameBaseName);
+        item->plugin->setIsEnabled(item->isEnabled);
+        item->pluginData.mHasConfigureDialog = item->plugin->hasConfigureDialog();
+        mPluginDataList.append(item->pluginData);
     }
 }
 
@@ -133,6 +169,17 @@ QVector<PluginEditorCheckBeforeSend *> PluginEditorCheckBeforeSendManagerPrivate
     return lst;
 }
 
+PluginEditorCheckBeforeSend *PluginEditorCheckBeforeSendManagerPrivate::pluginFromIdentifier(const QString &id)
+{
+    QVector<PluginEditorCheckBeforeSendInfo>::ConstIterator end(mPluginList.constEnd());
+    for (QVector<PluginEditorCheckBeforeSendInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
+        if ((*it).pluginData.mIdentifier == id) {
+            return (*it).plugin;
+        }
+    }
+    return {};
+}
+
 PluginEditorCheckBeforeSendManager::PluginEditorCheckBeforeSendManager(QObject *parent)
     : QObject(parent),
       d(new MessageComposer::PluginEditorCheckBeforeSendManagerPrivate(this))
@@ -149,12 +196,27 @@ PluginEditorCheckBeforeSendManager *PluginEditorCheckBeforeSendManager::self()
     return sInstance->pluginManager;
 }
 
-QString PluginEditorCheckBeforeSendInfo::saveName() const
-{
-    return QFileInfo(metaData.fileName()).baseName();
-}
-
 QVector<PluginEditorCheckBeforeSend *> PluginEditorCheckBeforeSendManager::pluginsList() const
 {
     return d->pluginsList();
 }
+
+QString PluginEditorCheckBeforeSendManager::configGroupName() const
+{
+    return d->configGroupName();
+}
+
+QString PluginEditorCheckBeforeSendManager::configPrefixSettingKey() const
+{
+    return d->configPrefixSettingKey();
+}
+
+QVector<PimCommon::PluginUtilData> PluginEditorCheckBeforeSendManager::pluginsDataList() const
+{
+    return d->pluginsDataList();
+}
+
+PluginEditorCheckBeforeSend *PluginEditorCheckBeforeSendManager::pluginFromIdentifier(const QString &id)
+{
+    return d->pluginFromIdentifier(id);
+}
