@@ -31,6 +31,7 @@
 
 #include <KLocalizedString>
 #include <KIconLoader>
+#include <KColorScheme>
 
 #include <grantlee/templateloader.h>
 #include <grantlee/engine.h>
@@ -112,10 +113,7 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
     headerObject.insert(QStringLiteral("subjectDir"), d->headerStyleUtil.subjectDirectionString(message));
 
     headerObject.insert(QStringLiteral("subjecti18n"), i18n("Subject:"));
-    KTextToHTML::Options flags = KTextToHTML::PreserveSpaces;
-    if (MessageViewer::MessageViewerSettings::self()->showEmoticons()) {
-        flags |= KTextToHTML::ReplaceSmileys;
-    }
+    const KTextToHTML::Options flags = KTextToHTML::PreserveSpaces | KTextToHTML::ReplaceSmileys;
 
     headerObject.insert(QStringLiteral("subject"), d->headerStyleUtil.subjectString(message, flags));
 
@@ -166,11 +164,10 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
     headerObject.insert(QStringLiteral("senderi18n"), i18n("Sender:"));
     headerObject.insert(QStringLiteral("listidi18n"), i18n("List-Id:"));
 
-    if (message->headerByType("List-Id")) {
-        headerObject.insert(QStringLiteral("listid"), message->headerByType("List-Id")->asUnicodeString());
+    if (auto hrd = message->headerByType("List-Id")) {
+        headerObject.insert(QStringLiteral("listid"), hrd->asUnicodeString());
     }
 
-
     const QString spamHtml = d->headerStyleUtil.spamStatus(message);
     if (!spamHtml.isEmpty()) {
         headerObject.insert(QStringLiteral("spamstatusi18n"), i18n("Spam Status:"));
@@ -190,18 +187,18 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
             headerObject.insert(QStringLiteral("useragent"), d->headerStyleUtil.strToHtml(hdr->asUnicodeString()));
         }
 
-        if (message->headerByType("X-Mailer")) {
-            headerObject.insert(QStringLiteral("xmailer"), d->headerStyleUtil.strToHtml(message->headerByType("X-Mailer")->asUnicodeString()));
+        if (auto hrd = message->headerByType("X-Mailer")) {
+            headerObject.insert(QStringLiteral("xmailer"), d->headerStyleUtil.strToHtml(hrd->asUnicodeString()));
         }
     }
 
-    if (message->headerByType("Resent-From")) {
+    if (message->hasHeader("Resent-From")) {
         headerObject.insert(QStringLiteral("resentfromi18n"), i18n("resent from"));
         const QVector<KMime::Types::Mailbox> resentFrom = d->headerStyleUtil.resentFromList(message);
         headerObject.insert(QStringLiteral("resentfrom"), StringUtil::emailAddrAsAnchor(resentFrom, StringUtil::DisplayFullAddress));
     }
 
-    if (message->headerByType("Resent-To")) {
+    if (message->hasHeader("Resent-To")) {
         const QVector<KMime::Types::Mailbox> resentTo = d->headerStyleUtil.resentToList(message);
         headerObject.insert(QStringLiteral("resenttoi18n"), i18np("receiver was", "receivers were", resentTo.count()));
         headerObject.insert(QStringLiteral("resentto"), StringUtil::emailAddrAsAnchor(resentTo, StringUtil::DisplayFullAddress));
@@ -254,10 +251,10 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
 
     Q_FOREACH (QString header, displayExtraHeaders) {
         const QByteArray baHeader = header.toLocal8Bit();
-        if (message->headerByType(baHeader.constData())) {
+        if (auto hrd = message->headerByType(baHeader.constData())) {
             //Grantlee doesn't support '-' in variable name => remove it.
             header = header.remove(QLatin1Char('-'));
-            headerObject.insert(header, message->headerByType(baHeader.constData())->asUnicodeString());
+            headerObject.insert(header, hrd->asUnicodeString());
         }
     }
 
