@@ -34,8 +34,7 @@
 #include <MimeTreeParser/ObjectTreeParser>
 #include <GrantleeTheme/QtResourceTemplateLoader>
 
-#include <Libkleo/CryptoBackend>
-#include <Libkleo/CryptoBackendFactory>
+#include <QGpgME/Protocol>
 
 #include <MessageCore/StringUtil>
 
@@ -63,7 +62,7 @@ using namespace MimeTreeParser;
 using namespace MessageViewer;
 
 Q_DECLARE_METATYPE(GpgME::DecryptionResult::Recipient)
-Q_DECLARE_METATYPE(const Kleo::CryptoBackend::Protocol *)
+Q_DECLARE_METATYPE(const QGpgME::Protocol *)
 
 /** Check if the newline at position @p newLinePos in string @p s
     seems to separate two paragraphs (important for correct BiDi
@@ -147,7 +146,7 @@ static const int SIG_FRAME_COL_UNDEF = 99;
 #define SIG_FRAME_COL_RED    -1
 #define SIG_FRAME_COL_YELLOW  0
 #define SIG_FRAME_COL_GREEN   1
-QString sigStatusToString(const Kleo::CryptoBackend::Protocol *cryptProto,
+QString sigStatusToString(const QGpgME::Protocol *cryptProto,
                           int status_code,
                           GpgME::Signature::Summary summary,
                           int &frameColor,
@@ -159,7 +158,7 @@ QString sigStatusToString(const Kleo::CryptoBackend::Protocol *cryptProto,
     showKeyInfos = true;
     QString result;
     if (cryptProto) {
-        if (cryptProto == Kleo::CryptoBackendFactory::instance()->openpgp()) {
+        if (cryptProto == QGpgME::openpgp()) {
             // process enum according to it's definition to be read in
             // GNU Privacy Guard CVS repository /gpgme/gpgme/gpgme.h
             switch (status_code) {
@@ -170,7 +169,7 @@ QString sigStatusToString(const Kleo::CryptoBackend::Protocol *cryptProto,
                 result = i18n("Good signature");
                 break;
             case 2: // GPGME_SIG_STAT_BAD
-                result = i18n("<b>Bad</b> signature");
+                result = i18n("Bad signature");
                 break;
             case 3: // GPGME_SIG_STAT_NOKEY
                 result = i18n("No public key to verify the signature");
@@ -196,7 +195,7 @@ QString sigStatusToString(const Kleo::CryptoBackend::Protocol *cryptProto,
                 result.clear();   // do *not* return a default text here !
                 break;
             }
-        } else if (cryptProto == Kleo::CryptoBackendFactory::instance()->smime()) {
+        } else if (cryptProto == QGpgME::smime()) {
             // process status bits according to SigStatus_...
             // definitions in kdenetwork/libkdenetwork/cryptplug.h
 
@@ -296,7 +295,7 @@ QString sigStatusToString(const Kleo::CryptoBackend::Protocol *cryptProto,
             if (SIG_FRAME_COL_GREEN == frameColor) {
                 result = i18n("Good signature.");
             } else if (SIG_FRAME_COL_RED == frameColor) {
-                result = i18n("<b>Bad</b> signature.");
+                result = i18n("Bad signature.");
             } else {
                 result.clear();
             }
@@ -419,9 +418,8 @@ public:
 class MimeTreeParser::DefaultRendererPrivate
 {
 public:
-    DefaultRendererPrivate(DefaultRenderer *qPtr, const Interface::MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper)
+    DefaultRendererPrivate(const Interface::MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper)
         : mMsgPart(msgPart)
-        , q(qPtr)
         , mOldWriter(msgPart->htmlWriter())
         , mCSSHelper(cssHelper)
     {
@@ -656,7 +654,7 @@ public:
 
     QString quotedHTML(const QString &s)
     {
-        assert(cssHelper());
+        Q_ASSERT(cssHelper());
 
         KTextToHTML::Options convertFlags = KTextToHTML::PreserveSpaces | KTextToHTML::HighlightText;
         if (source()->showEmoticons()) {
@@ -689,7 +687,6 @@ public:
         int currQuoteLevel = -2; // -2 == no previous lines
         bool curHidden = false; // no hide any block
 
-
         QString collapseIconPath;
         QString mExpandIconPath;
         if (source()->showExpandQuotesMark()) {
@@ -874,9 +871,10 @@ public:
 
         auto preferredMode = mp->source()->preferredMode();
         bool isHtmlPreferred = (preferredMode == Util::Html) || (preferredMode == Util::MultipartHtml);
+        const bool isPrinting = mp->source()->isPrinting();
         block.setProperty("htmlMail", isHtmlPreferred);
         block.setProperty("loadExternal", mp->source()->htmlLoadExternal());
-
+        block.setProperty("isPrinting", isPrinting);
         {
             QString extraHead;
             QString bodyText = processHtml(mp->mBodyHTML, extraHead);
@@ -961,7 +959,7 @@ public:
         const auto metaData = mp->mMetaData;
         auto cryptoProto = mp->mCryptoProto;
 
-        const bool isSMIME = cryptoProto && (cryptoProto == Kleo::CryptoBackendFactory::instance()->smime());
+        const bool isSMIME = cryptoProto && (cryptoProto == QGpgME::smime());
 
         Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(":/signedmessagepart.html"));
         Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
@@ -1212,7 +1210,7 @@ public:
         }
         return htmlWriter->html;
     }
- 
+
     QString render(const EncryptedMessagePart::Ptr &mp)
     {
         auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
@@ -1255,7 +1253,7 @@ public:
 
             auto mode = mp->preferredMode();
             if (mode == MimeTreeParser::Util::MultipartPlain && mp->text().trimmed().isEmpty()) {
-                foreach(const auto m, mp->availableModes()) {
+                foreach (const auto m, mp->availableModes()) {
                     if (m != MimeTreeParser::Util::MultipartPlain) {
                         mode = m;
                         break;
@@ -1390,14 +1388,13 @@ public:
     QString mHtml;
     Interface::MessagePart::Ptr mMsgPart;
 private:
-    DefaultRenderer *q;
     HtmlWriter *mOldWriter;
 
     CSSHelperBase *mCSSHelper;
 };
 
 DefaultRenderer::DefaultRenderer(const MimeTreeParser::Interface::MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper)
-    : d(new MimeTreeParser::DefaultRendererPrivate(this, msgPart, cssHelper))
+    : d(new MimeTreeParser::DefaultRendererPrivate(msgPart, cssHelper))
 {
 }
 
