@@ -132,11 +132,12 @@ public:
         View = 3,
         Save = 4,
         Properties = 5,
-        ChiasmusEncrypt = 6,
-        Delete = 7,
-        Edit = 8,
-        Copy = 9,
-        ScrollTo = 10
+        Delete = 6,
+        Edit = 7,
+        Copy = 8,
+        ScrollTo = 9,
+        ReplyMessageToAuthor = 10,
+        ReplyMessageToAll = 11
     };
 
     enum MailAction {
@@ -277,6 +278,7 @@ public:
     QAction *saveAsAction() const;
     QAction *saveMessageDisplayFormatAction() const;
     QAction *resetMessageDisplayFormatAction() const;
+    QAction *disableEmoticonAction() const;
     KActionMenu *shareServiceUrlMenu() const;
     HeaderStylePlugin *headerStylePlugin() const;
     void setPluginName(const QString &pluginName);
@@ -323,6 +325,10 @@ public:
     QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
 
     void runJavaScript(const QString &code);
+    void setPrintElementBackground(bool printElementBackground);
+
+    bool printingMode() const;
+
 Q_SIGNALS:
     void moveMessageToTrash();
     void pageIsScrolledToBottom(bool);
@@ -357,6 +363,8 @@ Q_SIGNALS:
     /// Emitted when the message should be shown in a separate window
     void showMessage(const KMime::Message::Ptr &message, const QString &encoding);
 
+    void replyMessageTo(const KMime::Message::Ptr &message, bool replyToAll);
+
     void deleteMessage(const Akonadi::Item &);
 
     /// Emitted when the item, previously set with setMessageItem, has been removed.
@@ -364,6 +372,8 @@ Q_SIGNALS:
 
     void makeResourceOnline(MessageViewer::Viewer::ResourceOnlineMode mode);
 
+    void printingFinished();
+
 private:
     void initialize();
 
