@@ -29,8 +29,10 @@ namespace MailWebEngineScript
 {
 MESSAGEVIEWER_EXPORT QString injectAttachments(const QString &delayedHtml, const QString &element);
 MESSAGEVIEWER_EXPORT QString replaceInnerHtml(const QString &field, const QString &html);
-MESSAGEVIEWER_EXPORT QString manageShowHideAttachments();
-MESSAGEVIEWER_EXPORT QString manageExpandAddresses(const QString &field);
+MESSAGEVIEWER_EXPORT QString manageShowHideAttachments(bool hide);
+MESSAGEVIEWER_EXPORT QString manageShowHideToAddress(bool hide);
+MESSAGEVIEWER_EXPORT QString manageShowHideCcAddress(bool hide);
+MESSAGEVIEWER_EXPORT QString createShowHideAddressScript(const QString &field, bool hide);
 }
 }
 #endif // MAILWEBENGINESCRIPT_H
