@@ -33,7 +33,6 @@
 #include "mailsourceviewtextbrowserwidget.h"
 #include "messageviewer/messageviewerutil.h"
 #include "findbar/findbarsourceview.h"
-#include <kpimtextedit/htmlhighlighter.h>
 #include "kpimtextedit/slidecontainer.h"
 #include "PimCommon/PimUtil"
 #include "kpimtextedit/texttospeechwidget.h"
@@ -59,8 +58,7 @@ using namespace MessageViewer;
 MailSourceViewTextBrowserWidget::MailSourceViewTextBrowserWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout;
-    setLayout(lay);
+    QVBoxLayout *lay = new QVBoxLayout(this);
     lay->setMargin(0);
     mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget;
     mTextToSpeechWidget->setObjectName(QStringLiteral("texttospeech"));
@@ -127,7 +125,7 @@ void MailSourceViewTextBrowser::contextMenuEvent(QContextMenuEvent *event)
     QMenu *popup = createStandardContextMenu();
     if (popup) {
         popup->addSeparator();
-        popup->addAction(KStandardAction::find(this, SIGNAL(findText()), this));
+        popup->addAction(KStandardAction::find(this, &MailSourceViewTextBrowser::findText, this));
         //Code from KTextBrowser
         KIconTheme::assignIconsToContextMenu(isReadOnly() ? KIconTheme::ReadOnlyText
                                              : KIconTheme::TextEditor,
