@@ -33,9 +33,9 @@
 
 #include <KMime/Content>
 
-#include <qgpgme/qgpgme_version.h>
+#include <gpgme.h>
 
-#if QGPGME_VERSION < 0x010702
+#if GPGME_VERSION_NUMBER < 0x010702
     #include <Libkleo/Dn>
 #else
     #include <QGpgME/DN>
@@ -861,7 +861,7 @@ static int signatureToStatus(const GpgME::Signature &sig)
 
 QString prettifyDN(const char *uid)
 {
-#if QGPGME_VERSION < 0x010702
+#if GPGME_VERSION_NUMBER < 0x010702
     return Kleo::DN(uid).prettyDN();
 #else
     return QGpgME::DN(uid).prettyDN();
@@ -1213,6 +1213,9 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
                 foreach (const GpgME::DecryptionResult::Recipient &recipient, decryptResult.recipients()) {
                     mNoSecKey &= (recipient.status().code() == GPG_ERR_NO_SECKEY);
                 }
+                if (!mPassphraseError && !mNoSecKey) {          // GpgME do not detect passphrase error correctly
+                    mPassphraseError = true;
+                }
             }
         }
     }
