@@ -20,11 +20,10 @@
 #include "testdndwebengine.h"
 
 #include <QApplication>
-#include <QFile>
 #include <QVBoxLayout>
-#include <QDebug>
 #include <webengineview.h>
 #include <QTextEdit>
+#include <QDebug>
 
 TestDndWebEngine::TestDndWebEngine(QWidget *parent)
     : QWidget(parent)
@@ -37,7 +36,7 @@ TestDndWebEngine::TestDndWebEngine(QWidget *parent)
     pageView->load(QUrl(QStringLiteral("http://www.planetkde.org")));
     layout->addWidget(pageView);
 
-    webEngineView = new QWebEngineView(this);
+    webEngineView = new WebEngineViewBase(this);
     webEngineView->load(QUrl(QStringLiteral("http://www.kde.org")));
     layout->addWidget(webEngineView);
 
@@ -59,3 +58,33 @@ int main(int argc, char *argv[])
     const int ret = app.exec();
     return ret;
 }
+
+WebEngineViewBase::WebEngineViewBase(QWidget *parent)
+    : QWebEngineView(parent)
+{
+    qDebug() << "WebEngineViewBase::WebEngineViewBase(QWidget *parent)" << this;
+}
+
+void WebEngineViewBase::dragEnterEvent(QDragEnterEvent *e)
+{
+    qDebug() << " void WebEngineViewBase::dragEnterEvent(QDragEnterEvent *e)";
+    QWebEngineView::dragEnterEvent(e);
+}
+
+void WebEngineViewBase::dragLeaveEvent(QDragLeaveEvent *e)
+{
+    qDebug() << " void WebEngineViewBase::dragLeaveEvent(QDragEnterEvent *e)";
+    QWebEngineView::dragLeaveEvent(e);
+}
+
+void WebEngineViewBase::dragMoveEvent(QDragMoveEvent *e)
+{
+    qDebug() << "void WebEngineViewBase::dragMoveEvent(QDragMoveEvent *e)";
+    QWebEngineView::dragMoveEvent(e);
+}
+
+void WebEngineViewBase::dropEvent(QDropEvent *e)
+{
+    qDebug() << " void WebEngineViewBase::dropEvent(QDropEvent *e)";
+    QWebEngineView::dropEvent(e);
+}
