@@ -18,22 +18,43 @@
 */
 
 #include "testjquerysupportwebengine.h"
-#include <QHBoxLayout>
 #include <QApplication>
-#include <QWebEngineView>
 #include <WebEngineViewer/WebEnginePage>
-#include <QDebug>
 #include <webengineview.h>
 #include <QPushButton>
-#include <QMessageBox>
 #include <QTextEdit>
+#include <QVBoxLayout>
+#include <QPointer>
 #include <WebEngineViewer/WebEngineManageScript>
+#include <WebEngineViewer/WebEnginePage>
+
+template<typename Arg, typename R, typename C>
+struct InvokeWrapper {
+    QPointer<R> receiver;
+    void (C::*memberFunction)(Arg);
+    void operator()(Arg result)
+    {
+        if (receiver) {
+            (receiver->*memberFunction)(result);
+        }
+    }
+};
+
+template<typename Arg, typename R, typename C>
+
+InvokeWrapper<Arg, R, C> invoke(R *receiver, void (C::*memberFunction)(Arg))
+{
+    InvokeWrapper<Arg, R, C> wrapper = {receiver, memberFunction};
+    return wrapper;
+}
 
 TestJQuerySupportWebEngine::TestJQuerySupportWebEngine(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *vboxLayout = new QVBoxLayout(this);
     pageView = new WebEngineViewer::WebEngineView(this);
+    WebEngineViewer::WebEnginePage *page = new WebEngineViewer::WebEnginePage(this);
+    pageView->setPage(page);
     vboxLayout->addWidget(pageView);
 
     pageView->initializeJQueryScript();
@@ -41,6 +62,7 @@ TestJQuerySupportWebEngine::TestJQuerySupportWebEngine(QWidget *parent)
     mEditor->setAcceptRichText(false);
     mEditor->setPlainText(QStringLiteral("qt.jQuery('img').each( function () { qt.jQuery(this).css('-webkit-transition', '-webkit-transform 2s'); qt.jQuery(this).css('-webkit-transform', 'rotate(180deg)') } ); undefined"));
     vboxLayout->addWidget(mEditor);
+    connect(page, &WebEngineViewer::WebEnginePage::showConsoleMessage, this, &TestJQuerySupportWebEngine::slotShowConsoleMessage);
 
     QPushButton *executeQuery = new QPushButton(QStringLiteral("Execute Query"), this);
     connect(executeQuery, &QPushButton::clicked, this, &TestJQuerySupportWebEngine::slotExecuteQuery);
@@ -54,12 +76,23 @@ TestJQuerySupportWebEngine::~TestJQuerySupportWebEngine()
 
 }
 
+void TestJQuerySupportWebEngine::slotShowConsoleMessage(const QString &message)
+{
+    qDebug() << "TestJQuerySupportWebEngine::slotShowConsoleMessage :" << message;
+}
+
+void TestJQuerySupportWebEngine::handleResultScript(const QVariant &var)
+{
+    qDebug() << " void TestJQuerySupportWebEngine::handleResultScript(const QVariant &var)" << var;
+}
+
 void TestJQuerySupportWebEngine::slotExecuteQuery()
 {
     const QString code = mEditor->toPlainText();
     if (!code.isEmpty()) {
 #if QT_VERSION >= 0x050700
-        pageView->page()->runJavaScript(code, WebEngineViewer::WebEngineManageScript::scriptWordId());
+        pageView->page()->runJavaScript(code, WebEngineViewer::WebEngineManageScript::scriptWordId(),
+                                        invoke(this, &TestJQuerySupportWebEngine::handleResultScript));
 #else
         pageView->page()->runJavaScript(code);
 #endif
