@@ -22,7 +22,8 @@
 using namespace WebEngineViewer;
 
 NetworkPluginUrlInterceptor::NetworkPluginUrlInterceptor(QObject *parent)
-    : QObject(parent)
+    : QObject(parent),
+      mIsEnabled(false)
 {
 
 }
@@ -32,13 +33,22 @@ NetworkPluginUrlInterceptor::~NetworkPluginUrlInterceptor()
 
 }
 
-bool NetworkPluginUrlInterceptor::hasConfigureSupport() const
+bool NetworkPluginUrlInterceptor::hasConfigureDialog() const
 {
     return false;
 }
 
-NetworkPluginUrlInterceptorConfigureWidgetSetting NetworkPluginUrlInterceptor::createConfigureWidget(QWidget *parent)
+void NetworkPluginUrlInterceptor::showConfigureDialog(QWidget *parent)
 {
     Q_UNUSED(parent);
-    return {};
+}
+
+void NetworkPluginUrlInterceptor::setIsEnabled(bool enabled)
+{
+    mIsEnabled = enabled;
+}
+
+bool NetworkPluginUrlInterceptor::isEnabled() const
+{
+    return mIsEnabled;
 }
