@@ -23,76 +23,76 @@ using namespace WebEngineViewer;
 
 QString WebEngineScript::findAllImages()
 {
-    const QString source = QLatin1String("(function() {"
-                                         "var out = [];"
-                                         "var imgs = document.getElementsByTagName('img');"
-                                         "for (var i = 0; i < imgs.length; ++i) {"
-                                         "    var e = imgs[i];"
-                                         "    out.push({"
-                                         "        src: e.src"
-                                         "    });"
-                                         "}"
-                                         "return out;"
-                                         "})()");
+    const QString source = QStringLiteral("(function() {"
+                                          "var out = [];"
+                                          "var imgs = document.getElementsByTagName('img');"
+                                          "for (var i = 0; i < imgs.length; ++i) {"
+                                          "    var e = imgs[i];"
+                                          "    out.push({"
+                                          "        src: e.src"
+                                          "    });"
+                                          "}"
+                                          "return out;"
+                                          "})()");
 
     return source;
 }
 
 QString WebEngineScript::findAllScripts()
 {
-    const QString source = QLatin1String("(function() {"
-                                         "var out = [];"
-                                         "var scripts = document.getElementsByTagName('script');"
-                                         "for (var i = 0; i < scripts.length; ++i) {"
-                                         "    var e = scripts[i];"
-                                         "    out.push({"
-                                         "        src: e.src"
-                                         "    });"
-                                         "}"
-                                         "return out;"
-                                         "})()");
+    const QString source = QStringLiteral("(function() {"
+                                          "var out = [];"
+                                          "var scripts = document.getElementsByTagName('script');"
+                                          "for (var i = 0; i < scripts.length; ++i) {"
+                                          "    var e = scripts[i];"
+                                          "    out.push({"
+                                          "        src: e.src"
+                                          "    });"
+                                          "}"
+                                          "return out;"
+                                          "})()");
 
     return source;
 }
 
 QString WebEngineScript::findAllAnchors()
 {
-    const QString source = QLatin1String("(function() {"
-                                         "var out = [];"
-                                         "var anchors = document.getElementsByTagName('a');"
-                                         "for (var i = 0; i < anchors.length; ++i) {"
-                                         "    var r = anchors[i].getBoundingClientRect();"
-                                         "    out.push({"
-                                         "        src: anchors[i].href,"
-                                         "        title: anchors[i].title,"
-                                         "        boudingRect: [r.top, r.left, r.width, r.height]"
-                                         "    });"
-                                         "}"
-                                         "return out;"
-                                         "})()");
+    const QString source = QStringLiteral("(function() {"
+                                          "var out = [];"
+                                          "var anchors = document.getElementsByTagName('a');"
+                                          "for (var i = 0; i < anchors.length; ++i) {"
+                                          "    var r = anchors[i].getBoundingClientRect();"
+                                          "    out.push({"
+                                          "        src: anchors[i].href,"
+                                          "        title: anchors[i].title,"
+                                          "        boudingRect: [r.top, r.left, r.width, r.height]"
+                                          "    });"
+                                          "}"
+                                          "return out;"
+                                          "})()");
 
     return source;
 }
 
 QString WebEngineScript::findAllAnchorsAndForms()
 {
-    const QString source = QLatin1String("(function() {"
-                                         "var res = [];"
-                                         "var out = [];"
-                                         "var anchors = document.getElementsByTagName('a');"
-                                         "for (var i = 0; i < anchors.length; ++i) {"
-                                         "    out.push({"
-                                         "        src: anchors[i].href,"
-                                         "        title: anchors[i].title"
-                                         "    });"
-                                         "}"
-                                         "var forms = document.getElementsByTagName('form');"
-                                         "res.push({"
-                                         "    anchors: out,"
-                                         "    forms:  forms.length"
-                                         "    });"
-                                         "return res;"
-                                         "})()");
+    const QString source = QStringLiteral("(function() {"
+                                          "var res = [];"
+                                          "var out = [];"
+                                          "var anchors = document.getElementsByTagName('a');"
+                                          "for (var i = 0; i < anchors.length; ++i) {"
+                                          "    out.push({"
+                                          "        src: anchors[i].href,"
+                                          "        title: anchors[i].title"
+                                          "    });"
+                                          "}"
+                                          "var forms = document.getElementsByTagName('form');"
+                                          "res.push({"
+                                          "    anchors: out,"
+                                          "    forms:  forms.length"
+                                          "    });"
+                                          "return res;"
+                                          "})()");
 
     return source;
 }
@@ -121,7 +121,6 @@ QString WebEngineScript::searchElementPosition(const QString &elementStr)
                            "    var geometry = element.getBoundingClientRect(); "
                            "    [(geometry.left + window.scrollX), (geometry.top + window.scrollY)]; "
                            "}").arg(elementStr);
-    //qDebug()<<" source "<<source;
     return source;
 }
 
@@ -132,8 +131,6 @@ QString WebEngineScript::scrollPercentage(int percent)
                            "var height = docElement.clientHeight;"
                            "var newPosition = current + height * %1 /100;"
                            "window.scrollTo(window.scrollX, newPosition);").arg(percent);
-
-    //qDebug() << "QString WebEngineScript::scrollPercentage(int percent) " << source;
     return source;
 }
 
@@ -151,8 +148,7 @@ QString WebEngineScript::scrollDown(int pixel)
 
 QString WebEngineScript::scrollToPosition(const QPoint &pos)
 {
-    const QString source = QString::fromLatin1("window.scrollTo(%1, %2); [window.scrollX, window.scrollY];").arg(pos.x()).arg(pos.y());
-    //qDebug()<<" source "<<source;
+    const QString source = QString::fromLatin1("window.scrollTo(%1, %2); [window.scrollX, window.scrollY];").arg(pos.x(), pos.y());
     return source;
 }
 
@@ -170,14 +166,12 @@ QString WebEngineScript::setStyleToElement(const QString &elementStr, const QStr
     const QString source = QString::fromLatin1("var element = document.getElementById('%1'); "
                            "if (element) { "
                            "    element.style = '%2';"
-                           "}").arg(elementStr).arg(style);
-    //qDebug() << "QString WebEngineScript::setStyleToElement(const QString &elementStr, const QString &style) " << source;
+                           "}").arg(elementStr, style);
     return source;
 }
 
 QString WebEngineScript::scrollToRelativePosition(qreal pos)
 {
-    //TODO verify it
     const QString source = QString::fromLatin1("window.scrollTo(window.scrollX, %1); [window.scrollX, window.scrollY];").arg(pos);
     return source;
 }
@@ -195,4 +189,3 @@ QString WebEngineScript::isScrolledToBottom()
                                "return Boolean(isAtBottom); "
                                "}());");
 }
-
